You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@openoffice.apache.org by al...@apache.org on 2012/10/19 10:42:37 UTC

svn commit: r1399997 - /incubator/ooo/branches/alg/aw080/main/svx/source/sdr/contact/viewcontactofsdrobjcustomshape.cxx

Author: alg
Date: Fri Oct 19 08:42:36 2012
New Revision: 1399997

URL: http://svn.apache.org/viewvc?rev=1399997&view=rev
Log:
#119863# added that patch to aw080 due to later possible conflicts

Modified:
    incubator/ooo/branches/alg/aw080/main/svx/source/sdr/contact/viewcontactofsdrobjcustomshape.cxx

Modified: incubator/ooo/branches/alg/aw080/main/svx/source/sdr/contact/viewcontactofsdrobjcustomshape.cxx
URL: http://svn.apache.org/viewvc/incubator/ooo/branches/alg/aw080/main/svx/source/sdr/contact/viewcontactofsdrobjcustomshape.cxx?rev=1399997&r1=1399996&r2=1399997&view=diff
==============================================================================
--- incubator/ooo/branches/alg/aw080/main/svx/source/sdr/contact/viewcontactofsdrobjcustomshape.cxx (original)
+++ incubator/ooo/branches/alg/aw080/main/svx/source/sdr/contact/viewcontactofsdrobjcustomshape.cxx Fri Oct 19 08:42:36 2012
@@ -219,11 +219,17 @@ namespace sdr
 				xRetval = drawinglayer::primitive2d::Primitive2DSequence(&xReference, 1);
 			}
 
-			// always append an invisible outline for the cases where no visible content exists
-			drawinglayer::primitive2d::appendPrimitive2DReferenceToPrimitive2DSequence(xRetval, 
-				drawinglayer::primitive2d::createHiddenGeometryPrimitives2D(
-					false, 
-					aObjectRange));
+			// #119863# always append an invisible outline for the cases where no visible content exists
+            if(true)
+            {
+				// get object transformation
+				const basegfx::B2DHomMatrix& rObjectMatrix(GetCustomShapeObj().getSdrObjectTransformation());
+
+                drawinglayer::primitive2d::appendPrimitive2DReferenceToPrimitive2DSequence(xRetval, 
+				    drawinglayer::primitive2d::createHiddenGeometryPrimitives2D(
+					    false, 
+					    rObjectMatrix));
+            }
 
 			return xRetval;
 		}